==> deepin-font-installer_1.0.4.orig.tar.xz: deepin-font-installer-1.0.4/deepin-font-installer/translations/deepin-font-installer_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.1">
<context>
    <name>HomePage</name>
    <message>
        <source>Drag font file here</source>
        <translation>Sleep hier het lettertypebestand</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation>Selecteer bestand</translation>
    </message>
</context>
<context>
    <name>ListItem</name>
    <message>
        <source>Installed</source>
        <translation>Geïnstalleerd</translation>
    </message>
    <message>
        <source>Other version installed: %1</source>
        <translation>Andere versie geïnstalleerd: %1</translation>
    </message>
    <message>
        <source>Installing</source>
        <translation>Bezig met installeren</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Deepin Font Installer</source>
        <translation>Deepin Lettertype Installatie</translation>
    </message>
    <message>
        <source>Deepin Font Installer is used to install and uninstall font file for users with bulk install function.</source>
        <translation>Deepin Lettertype Installatie wordt gebruikt om lettertypebestanden te installeren, en te de-installeren, voor gebruikers via de massa-installatiefunctie.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Deepin Font Installer</source>
        <translation>Deepin Lettertype Installatie</translation>
    </message>
    <message>
        <source>Bulk Install</source>
        <translation>Massa installatie</translation>
    </message>
</context>
<context>
    <name>MultiFilePage</name>
    <message>
        <source>Install</source>
        <translation>Installeren</translation>
    </message>
    <message>
        <source>Installed successfully</source>
        <translation>Succesvol geïnstalleerd</translation>
    </message>
    <message>
        <source>View font directory</source>
        <translation>Lettertypemap weergeven</translation>
    </message>
    <message>
        <source>Refreshing font cache, please wait...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SingleFilePage</name>
    <message>
        <source>Install</source>
        <translation>Installeren</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Opnieuw installeren</translation>
    </message>
    <message>
        <source>View font directory</source>
        <translation>Lettertypemap weergeven</translation>
    </message>
    <message>
        <source>Style: </source>
        <translation>Stijl:</translation>
    </message>
    <message>
        <source>Type: </source>
        <translation>Type:</translation>
    </message>
    <message>
        <source>Version: </source>
        <translation>Versie:</translation>
    </message>
    <message>
        <source>Copyright: </source>
        <translation>Auteursrecht:</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Beschrijving:</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Dezelfde versie geïnstalleerd</translation>
    </message>
    <message>
        <source>Installed successfully</source>
        <translation>Succesvol geïnstalleerd</translation>
    </message>
    <message>
        <source>Removed successfully</source>
        <translation>Succesvol verwijderd</translation>
    </message>
    <message>
        <source>Other version installed: %1</source>
        <translation>Andere versie geïnstalleerd: %1</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Klaar</translation>
    </message>
</context>
</TS>

==> deepin-font-installer_1.1.5.1.orig.tar.xz: deepin-font-installer-1.1.5.1/deepin-font-installer/translations/deepin-font-installer_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.1">
<context>
    <name>HomePage</name>
    <message>
        <source>Drag font file here</source>
        <translation>Versleep lettertypebestand hierheen</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation>Selecteer bestand</translation>
    </message>
</context>
<context>
    <name>ListItem</name>
    <message>
        <source>Installed</source>
        <translation>Geïnstalleerd</translation>
    </message>
    <message>
        <source>Other version installed: %1</source>
        <translation>Andere versie geïnstalleerd: %1</translation>
    </message>
    <message>
        <source>Installing</source>
        <translation>Bezig met installeren</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Dezelfde versie geïnstalleerd</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Deepin Font Installer</source>
        <translation>Deepin Lettertype-installatie</translation>
    </message>
    <message>
        <source>Deepin Font Installer is used to install and uninstall font file for users with bulk install function.</source>
        <translation>Deepin Lettertype-installatie wordt gebruikt om lettertypebestanden te installeren en deïnstalleren voor gebruikers via de massa-installatiefunctie.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Deepin Font Installer</source>
        <translation>Deepin Lettertype-installatie</translation>
    </message>
    <message>
        <source>Bulk Install</source>
        <translation>Massa-installatie</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Donker thema</translation>
    </message>
</context>
<context>
    <name>MultiFilePage</name>
    <message>
        <source>Install</source>
        <translation>Installeren</translation>
    </message>
    <message>
        <source>Installed successfully</source>
        <translation>Geïnstalleerd</translation>
    </message>
    <message>
        <source>View font directory</source>
        <translation>Lettertypemap tonen</translation>
    </message>
    <message>
        <source>Refreshing font cache, please wait...</source>
        <translation>Bezig met verversen van lettertypecache; even geduld...</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Onbekend</translation>
    </message>
</context>
<context>
    <name>SingleFilePage</name>
    <message>
        <source>Install</source>
        <translation>Installeren</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Herinstalleren</translation>
    </message>
    <message>
        <source>View font directory</source>
        <translation>Lettertypemap tonen</translation>
    </message>
    <message>
        <source>Style: </source>
        <translation>Stijl:</translation>
    </message>
    <message>
        <source>Type: </source>
        <translation>Type:</translation>
    </message>
    <message>
        <source>Version: </source>
        <translation>Versie:</translation>
    </message>
    <message>
        <source>Copyright: </source>
        <translation>Auteursrecht:</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Omschrijving:</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Dezelfde versie geïnstalleerd</translation>
    </message>
    <message>
        <source>Installed successfully</source>
        <translation>Geïnstalleerd</translation>
    </message>
    <message>
        <source>Removed successfully</source>
        <translation>Verwijderd</translation>
    </message>
    <message>
        <source>Other version installed: %1</source>
        <translation>Andere versie geïnstalleerd: %1</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Klaar</translation>
    </message>
</context>
</TS>
